@@ -1,3 +1,5 @@
+import logging
+
 from django import http
 
 from . import version
@@ -23,6 +25,11 @@ def HttpResponse(*args, **kwargs):
     return res
 
 
+def debug_log(msg):  # pragma: no cover
+    if settings.DEBUG:
+        logging.getLogger(__name__).warning(str(msg))
+
+
 class Settings:
     _defaults = {
         "DATA_BROWSER_ALLOW_PUBLIC": False,
