@@ -1,5 +1,4 @@
 import json
-import logging
 from collections import defaultdict
 
 from django.contrib.admin import site
@@ -10,8 +9,8 @@ from django.db import models
 from django.db.models.fields.reverse_related import ForeignObjectRel
 from django.forms.models import _get_foreign_key
 
-from .common import settings
-from .helpers import AnnotationDescriptor
+from .common import debug_log, settings
+from .helpers import AdminMixin, AnnotationDescriptor
 from .orm_fields import (
     _AGGREGATES,
     _FUNC_MAP,
@@ -92,12 +91,19 @@ def _get_all_admin_fields(request):
         else:
             obj = None
 
-        for f in flatten_fieldsets(admin.get_fieldsets(request, obj)):
-            # skip calculated fields on inlines
-            if not isinstance(admin, InlineModelAdmin) or hasattr(admin.model, f):
-                yield f
+        try:
+            fields = admin.get_fieldsets(request, obj)
+        except Exception as e:  # pragma: no cover
+            debug_log(e)  # ignore things like HaystackResultsAdmin
+        else:
+            for f in flatten_fieldsets(fields):
+                # skip calculated fields on inlines
+                if not isinstance(admin, InlineModelAdmin) or hasattr(admin.model, f):
+                    yield f
 
     def visible(model_admin, request):
+        if getattr(model_admin, "ddb_ignore", False):
+            return False
         if model_admin.has_change_permission(request):
             return True
         if hasattr(model_admin, "has_view_permission"):
@@ -106,25 +112,39 @@ def _get_all_admin_fields(request):
             return False  # pragma: no cover  Django < 2.1
 
     all_admin_fields = defaultdict(set)
+    hidden_fields = defaultdict(set)
     model_admins = {}
     for model, model_admin in site._registry.items():
         model_admins[model] = model_admin
         if visible(model_admin, request):
             all_admin_fields[model].update(from_fieldsets(model_admin, True))
             all_admin_fields[model].update(model_admin.get_list_display(request))
+            all_admin_fields[model].update(getattr(model_admin, "ddb_extra_fields", []))
             all_admin_fields[model].add(_OPEN_IN_ADMIN)
+            if isinstance(model_admin, AdminMixin):
+                all_admin_fields[model].update(model_admin._ddb_annotations())
+            hidden_fields[model].update(getattr(model_admin, "ddb_hide_fields", []))
 
             # check the inlines, these are already filtered for access
             for inline in model_admin.get_inline_instances(request):
-                try:
-                    fk_field = _get_foreign_key(model, inline.model, inline.fk_name)
-                except Exception:
-                    pass  # ignore things like GenericInlineModelAdmin
-                else:
-                    if inline.model not in model_admins:  # pragma: no branch
-                        model_admins[inline.model] = inline
-                    all_admin_fields[inline.model].update(from_fieldsets(inline, False))
-                    all_admin_fields[inline.model].add(fk_field.name)
+                if visible(inline, request):
+                    try:
+                        fk_field = _get_foreign_key(model, inline.model, inline.fk_name)
+                    except Exception as e:
+                        debug_log(e)  # ignore things like GenericInlineModelAdmin
+                    else:
+                        if inline.model not in model_admins:  # pragma: no branch
+                            model_admins[inline.model] = inline
+                        all_admin_fields[inline.model].update(
+                            from_fieldsets(inline, False)
+                        )
+                        all_admin_fields[inline.model].update(
+                            getattr(inline, "ddb_extra_fields", [])
+                        )
+                        all_admin_fields[inline.model].add(fk_field.name)
+                        hidden_fields[inline.model].update(
+                            getattr(inline, "ddb_hide_fields", [])
+                        )
 
     # we always have id and never pk
     for fields in all_admin_fields.values():
@@ -132,6 +152,11 @@ def _get_all_admin_fields(request):
         fields.discard("pk")
         fields.discard("__str__")
 
+    # throw away the hidden ones
+    for model, fields in hidden_fields.items():
+        for f in fields:
+            all_admin_fields[model].discard(f)
+
     return model_admins, all_admin_fields
 
 
@@ -177,17 +202,21 @@ def _get_calculated_field(request, field_name, model_name, model, admin, model_f
             return None
 
 
+def _fmt_choices(choices):
+    return [(value, str(label)) for value, label in choices]
+
+
 def _get_field_type(model, field_name, field):
     if isinstance(field, ArrayField) and isinstance(
         field.base_field, _STRING_FIELDS
     ):  # pragma: postgres
-        return StringArrayType, field.base_field.choices
+        return StringArrayType, _fmt_choices(field.base_field.choices)
     elif isinstance(field, ArrayField) and isinstance(
         field.base_field, _NUMBER_FIELDS
     ):  # pragma: postgres
-        return NumberArrayType, field.base_field.choices
+        return NumberArrayType, _fmt_choices(field.base_field.choices)
     elif isinstance(field, JSONField):  # pragma: json field
-        return JSONType, None
+        res = JSONType
     elif field.__class__ in _FIELD_TYPE_MAP:
         res = _FIELD_TYPE_MAP[field.__class__]
     else:
@@ -196,17 +225,16 @@ def _get_field_type(model, field_name, field):
                 res = field_type
                 break
         else:
-            if settings.DEBUG:  # pragma: no cover
-                logging.getLogger(__name__).warning(
-                    f"DDB {model.__name__}.{field_name} unsupported type {type(field).__name__}"
-                )
-            return UnknownType, None
+            debug_log(
+                f"DDB {model.__name__}.{field_name} unsupported type {type(field).__name__}"
+            )
+            res = UnknownType
 
     # Choice fields have different lookups
     if res is StringType and field.choices:
-        return StringChoiceType, field.choices
+        return StringChoiceType, _fmt_choices(field.choices)
     elif res is NumberType and field.choices:
-        return NumberChoiceType, field.choices
+        return NumberChoiceType, _fmt_choices(field.choices)
     else:
         return res, None
 
@@ -336,21 +364,28 @@ def _filter(qs, filter_, filter_str):
 
 
 def _cols_sub_query(bound_query):
-    row_fields = [f.unsorted() for f in bound_query.row_fields]
+    filters = [
+        filter_
+        for filter_ in bound_query.valid_filters
+        if filter_.orm_bound_field.filter_
+    ]
+
     return BoundQuery(
-        bound_query.model_name,
-        bound_query.col_fields + row_fields,
-        bound_query.valid_filters,
-        bound_query.limit,
+        bound_query.model_name, bound_query.col_fields, filters, bound_query.limit
     )
 
 
 def _rows_sub_query(bound_query):
-    col_fields = [f.unsorted() for f in bound_query.col_fields]
+    filters = [
+        filter_
+        for filter_ in bound_query.valid_filters
+        if filter_.orm_bound_field.filter_
+    ]
+    data_fields = [f for f in bound_query.data_fields if f.direction]
     return BoundQuery(
         bound_query.model_name,
-        bound_query.row_fields + col_fields,
-        bound_query.valid_filters,
+        bound_query.row_fields + data_fields,
+        filters,
         bound_query.limit,
     )
 
@@ -479,19 +514,27 @@ def get_results(request, bound_query, orm_models):
             res.append((field.queryset_path, v))
         return tuple(res)
 
-    col_keys = {}
-    for row in cols_res:
-        col_keys[get_fields(row, bound_query.bound_col_fields)] = None
-
-    row_keys = {}
-    for row in rows_res:
-        row_keys[get_fields(row, bound_query.bound_row_fields)] = None
-
     data = defaultdict(dict)
+    all_row_keys = set()
+    all_col_keys = set()
     for row in res:
         row_key = get_fields(row, bound_query.bound_row_fields)
         col_key = get_fields(row, bound_query.bound_col_fields)
         data[row_key][col_key] = dict(get_fields(row, bound_query.bound_data_fields))
+        all_row_keys.add(row_key)
+        all_col_keys.add(col_key)
+
+    col_keys = {}  # abuse dict to preserve order while removing duplicates
+    for row in cols_res:
+        key = get_fields(row, bound_query.bound_col_fields)
+        if key in all_col_keys:
+            col_keys[key] = None
+
+    row_keys = {}  # abuse dict to preserve order while removing duplicates
+    for row in rows_res:
+        key = get_fields(row, bound_query.bound_row_fields)
+        if key in all_row_keys:
+            row_keys[key] = None
 
     body = []
     for col_key in col_keys:
