@@ -18,10 +18,22 @@ class GenericInlineAdminInline(GenericInlineModelAdmin):
     model = models.GenericInlineAdmin
 
 
+class IgnoredAdminInline(admin.TabularInline):
+    model = models.Ignored
+    fields = ["name"]
+    ddb_ignore = True
+
+
+@admin.register(models.Ignored)
+class IgnoredAdmin(admin.ModelAdmin):
+    fields = ["name", "in_admin"]
+    ddb_ignore = True
+
+
 @admin.register(models.InAdmin)
 class InAdmin(admin.ModelAdmin):
     fields = ["name"]
-    inlines = [InlineAdminInline, GenericInlineAdminInline]
+    inlines = [InlineAdminInline, GenericInlineAdminInline, IgnoredAdminInline]
 
 
 @admin.register(models.Normal)
@@ -69,17 +81,21 @@ class ProductMixin:
         "created_time",
         "number_choice",
         "string_choice",
-        "hidden",
+        "hidden_calculated",
+        "hidden_inline",
+        "hidden_model",
     ]
-    readonly_fields = ["id", "is_onsale", "hidden"]
+    readonly_fields = ["id", "is_onsale", "hidden_calculated"]
 
     @ddb_hide
-    def hidden(self, obj):
+    def hidden_calculated(self, obj):
         return obj
 
 
 class ProductInline(ProductMixin, admin.TabularInline):
     model = models.Product
+    ddb_hide_fields = ["hidden_inline"]
+    ddb_extra_fields = ["extra_inline"]
 
 
 @admin.register(models.Producer)
@@ -105,7 +121,13 @@ class SKUInline(admin.TabularInline):
 class ProductAdmin(AdminMixin, ProductMixin, admin.ModelAdmin):
     inlines = [SKUInline]
     list_display = ["only_in_list_view", "annotated"]
+    ddb_hide_fields = ["hidden_model"]
+    ddb_extra_fields = ["extra_model"]
 
     @annotation
     def annotated(self, request, qs):
         return qs.annotate(annotated=F("name"))
+
+    @annotation
+    def stealth_annotation(self, request, qs):
+        return qs.annotate(stealth_annotation=F("name"))
