@@ -1,8 +1,21 @@
+from dataclasses import dataclass
+
 from django import forms
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.utils import timezone
+from django.utils.deconstruct import deconstructible
+from django.utils.translation import gettext_lazy as _
+
+
+@deconstructible
+@dataclass
+class Word:
+    name: str
+
+    def __str__(self):
+        return self.name
 
 
 class FakeField(models.Field):  # pragma: no cover
@@ -49,6 +62,11 @@ class InlineAdmin(models.Model):
     in_admin = models.ForeignKey(InAdmin, on_delete=models.CASCADE)
 
 
+class Ignored(models.Model):
+    name = models.TextField()
+    in_admin = models.ForeignKey(InAdmin, on_delete=models.CASCADE)
+
+
 class GenericInlineAdmin(models.Model):
     name = models.TextField()
     content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
@@ -101,14 +119,22 @@ class Product(models.Model):
     fake = FakeField()
     created_time = models.DateTimeField(default=timezone.now)
     only_in_list_view = models.TextField()
+    hidden_inline = models.TextField()
+    hidden_model = models.TextField()
+    extra_inline = models.TextField()
+    extra_model = models.TextField()
 
     not_in_admin = models.TextField()
     fk_not_in_admin = models.ForeignKey(InAdmin, null=True, on_delete=models.CASCADE)
     model_not_in_admin = models.ForeignKey(
         NotInAdmin, null=True, on_delete=models.CASCADE
     )
-    string_choice = models.CharField(max_length=8, choices=[("a", "A"), ("b", "B")])
-    number_choice = models.IntegerField(choices=[(1, "A"), (2, "B")], default=1)
+    string_choice = models.CharField(
+        max_length=8, choices=[("a", _("A")), ("b", Word("B"))]
+    )
+    number_choice = models.IntegerField(
+        choices=[(1, _("A")), (2, Word("B"))], default=1
+    )
 
     def is_onsale(self):
         return False
